==> warbleR_1.1.26.tar.gz: warbleR/R/deprec_funs.R <==
##############################################################################################################
#' deprecated functions and function names
#'
#' @keywords internal
#' @details functions that have been deprecated or moved to other packages.
#' @export


ffDTW <- ff_DTW <- function(...) write(file = "", x = "This function has been deprecated. DTW distances between fundamental frequency contours can be calculated using `freq_DTW`")

ffts <- ff_ts <- function(...) write(file = "", x = "This function has been deprecated. Fundamental frequency contours can be calculated using `freq_ts`")

dfts <- df_ts <- function(...) write(file = "", x = "This function has been deprecated. Dominant frequency contours can be calculated using `freq_ts`")

sp.en.ts <- entropy_ts <- function(...) write(file = "", x = "This function has been deprecated. Spectral entropy contours can be calculated using `freq_ts`")

imp.raven <- function(...) write(file = "", x = "This function has been moved to the Rraven package (imp_raven) \n try `install.packages('Rraven')`")

imp.syrinx <- function(...) write(file = "", x = "This function has been moved to the Rraven package (imp_syrinx) \n try `install.packages('Rraven')`")

quer_ml <- function(...) write(file = "", x = "This function has been removed temporarily due to API changes at Macaulay Library")

xcorr.graph <- function(...) write(file = "", x = "This function has been deprecated as it was not compatible with changes to improve performance in 'xcorr()' (use corrplot package instead)")

manualoc <- manual_loc <- function(...) write(file = "", x = "This function has been deprecated. Try Raven Software (Cornell Lab of Ornithology) or Audacity to manually annotate. The Rraven package (imp_raven) can be used for importing Raven annotations: try `install.packages('Rraven')`")

==> warbleR_1.1.28.tar.gz: warbleR/R/deprec_funs.R <==
##############################################################################################################
#' deprecated functions and function names
#'
#' @keywords internal
#' @details functions that have been deprecated or moved to other packages.
#' @export


ffDTW <- ff_DTW <- function(...) write(file = "", x = "This function has been deprecated. DTW distances between fundamental frequency contours can be calculated using `freq_DTW`")

freq_ts <- ff_ts <- function(...) write(file = "", x = "This function has been deprecated. Fundamental frequency contours can be calculated using `freq_ts`")

dfts <- df_ts <- function(...) write(file = "", x = "This function has been deprecated. Dominant frequency contours can be calculated using `freq_ts`")

sp.en.ts <- entropy_ts <- function(...) write(file = "", x = "This function has been deprecated. Spectral entropy contours can be calculated using `freq_ts`")

imp.raven <- function(...) write(file = "", x = "This function has been moved to the Rraven package (imp_raven) \n try `install.packages('Rraven')`")

imp.syrinx <- function(...) write(file = "", x = "This function has been moved to the Rraven package (imp_syrinx) \n try `install.packages('Rraven')`")

quer_ml <- function(...) write(file = "", x = "This function has been removed temporarily due to API changes at Macaulay Library")

xcorr.graph <- function(...) write(file = "", x = "This function has been deprecated as it was not compatible with changes to improve performance in 'xcorr()' (use corrplot package instead)")

manualoc <- manual_loc <- function(...) write(file = "", x = "This function has been deprecated. Try Raven Software (Cornell Lab of Ornithology) or Audacity to manually annotate. The Rraven package (imp_raven) can be used for importing Raven annotations: try `install.packages('Rraven')`")
